@@ -19,6 +19,7 @@ from pychess.Utils.Move import Move
 from pychess.Utils.eco import get_eco
 from pychess.Utils.Offer import Offer
 from pychess.Utils.TimeModel import TimeModel
+from pychess.Utils.DecisionSupportAlgorithm import DecisionSupportAlgorithm
 from pychess.Savers import html, txt
 from pychess.Variants.normal import NormalBoard
 
@@ -32,7 +33,7 @@ from .const import WAITING_TO_START, UNKNOWN_REASON, WHITE, ARTIFICIAL, RUNNING,
     ACTION_ERROR_NONE_TO_DECLINE, ADJOURN_OFFER, ADJOURNED, ABORT_OFFER, ABORTED, \
     ADJOURNED_AGREEMENT, PAUSE_OFFER, RESUME_OFFER, ACTION_ERROR_NONE_TO_ACCEPT, \
     ABORTED_AGREEMENT, WHITE_ENGINE_DIED, BLACK_ENGINE_DIED, WON_ADJUDICATION, \
-    UNDOABLE_STATES, DRAW_REPITITION, UNDOABLE_REASONS, UNFINISHED_STATES, \
+    UNDOABLE_STATES, DRAW_REPETITION, UNDOABLE_REASONS, UNFINISHED_STATES, \
     DRAW_50MOVES, HINT
 
 
@@ -130,6 +131,10 @@ class GameModel(GObject.GObject):
         self.reason = UNKNOWN_REASON
         self.curColor = WHITE
 
+        # support algorithm for new players
+        # type apparent : DecisionSupportAlgorithm
+        self.support_algorithm = DecisionSupportAlgorithm()
+
         if timemodel is None:
             self.timemodel = TimeModel()
         else:
@@ -253,6 +258,13 @@ class GameModel(GObject.GObject):
         log.debug("GameModel.setPlayers: <- emit players_changed")
         log.debug("GameModel.setPlayers: returning")
 
+        # when the players are set, it is known whether or not there is a bot
+        # we activate the support algorithm if there is one
+        # boolean to know if the game is against a bot
+        # activate support algorithm if that is the case
+        if self.isLocalGame():
+            self.support_algorithm.set_foe_as_bot()
+
     def color(self, player):
         if player is self.players[0]:
             return WHITE
@@ -320,6 +332,14 @@ class GameModel(GObject.GObject):
         yield from self.start_analyzer(analyzer_type)
 
     def on_analyze(self, analyzer, analysis):
+        def safe_int(p):
+            if p in [None, '']:
+                return 0
+            try:
+                return int(p)
+            except ValueError:
+                return 0
+
         if analysis and (self.practice_game or self.lesson_game):
             for i, anal in enumerate(analysis):
                 if anal is not None:
@@ -336,28 +356,38 @@ class GameModel(GObject.GObject):
             ply, pv, score, depth, nps = analysis[0]
             if score is not None and depth:
                 if analyzer.mode == ANALYZING:
-                    if (ply not in self.scores) or (int(self.scores[ply][2]) <= int(depth)):
+                    if (ply not in self.scores) or (safe_int(self.scores[ply][2]) <= safe_int(depth)):
                         self.scores[ply] = (pv, score, depth)
                         self.emit("analysis_changed", ply)
                 else:
-                    if (ply not in self.spy_scores) or (int(self.spy_scores[ply][2]) <= int(depth)):
+                    if (ply not in self.spy_scores) or (safe_int(self.spy_scores[ply][2]) <= safe_int(depth)):
                         self.spy_scores[ply] = (pv, score, depth)
 
-    def setOpening(self, ply=None):
+    def setOpening(self, ply=None, redetermine=False):
         if ply is None:
             ply = self.ply
-        if ply > 40:
-            return
 
-        if ply > 0:
-            opening = get_eco(self.getBoardAtPly(ply).board.hash)
-        else:
-            opening = None
+        opening = None
+        while ply >= self.lowply:
+            opening = get_eco(self.getBoardAtPly(ply).board.hash, exactPosition=True)
+            if opening is None and redetermine:
+                ply = ply - 1
+            else:
+                break
+
         if opening is not None:
             self.tags["ECO"] = opening[0]
             self.tags["Opening"] = opening[1]
             self.tags["Variation"] = opening[2]
-            self.emit("opening_changed")
+        else:
+            if redetermine:
+                if 'ECO' in self.tags:
+                    del self.tags['ECO']
+                if 'Opening' in self.tags:
+                    del self.tags['Opening']
+                if 'Variation' in self.tags:
+                    del self.tags['Variation']
+        self.emit("opening_changed")
 
     # Board stuff
 
@@ -646,7 +676,8 @@ class GameModel(GObject.GObject):
         else:
             fileobj = uri
             self.uri = None
-        saver.save(fileobj, self, position, flip)
+        with fileobj:
+            saver.save(fileobj, self, position, flip)
         self.needsSave = False
         self.emit("game_saved", uri)
 
@@ -719,6 +750,7 @@ class GameModel(GObject.GObject):
 
             while self.status in (PAUSED, RUNNING, DRAW, WHITEWON, BLACKWON):
                 curPlayer = self.players[self.curColor]
+
                 if self.timed:
                     log.debug("GameModel.run: id=%s, players=%s, self.ply=%s: updating %s's time" % (
                         id(self), str(self.players), str(self.ply), str(curPlayer)))
@@ -730,13 +762,16 @@ class GameModel(GObject.GObject):
                         id(self), str(self.players), self.ply, str(curPlayer)))
 
                     move = None
+                    # if the current player is a bot
                     if curPlayer.__type__ == ARTIFICIAL and book_depth_max > 0 and self.ply <= book_depth_max:
                         move = self.get_book_move()
                         log.debug("GameModel.run: id=%s, players=%s, self.ply=%s: got move=%s from book" % (
                             id(self), str(self.players), self.ply, move))
                         if move is not None:
                             curPlayer.set_board(self.boards[-1].move(move))
+                    # if the current player is not a bot
                     if move is None:
+
                         if self.ply > self.lowply:
                             move = yield from curPlayer.makeMove(self.boards[-1], self.moves[-1], self.boards[-2])
                         else:
@@ -855,7 +890,7 @@ class GameModel(GObject.GObject):
 
         if status != RUNNING and self.status in (WAITING_TO_START, PAUSED,
                                                  RUNNING):
-            if status == DRAW and reason in (DRAW_REPITITION, DRAW_50MOVES):
+            if status == DRAW and reason in (DRAW_REPETITION, DRAW_50MOVES):
                 if self.isEngine2EngineGame():
                     self.end(status, reason)
                     return
@@ -1005,7 +1040,7 @@ class GameModel(GObject.GObject):
             self.timemodel.undoMoves(moves)
 
         self.checkStatus()
-        self.setOpening()
+        self.setOpening(redetermine=True)
 
         self.emit("moves_undone", moves)
 
