@@ -30,7 +30,10 @@ class TimeModel(GObject.GObject):
 
         # time control (not necessarily where the game was resumed,
         # i.e. self.intervals[0][0])
-        self.intervals = [[secs], [bsecs]]
+        if secs == 0 and gain > 0:
+            self.intervals = [[gain], [gain]]
+        else:
+            self.intervals = [[secs], [bsecs]]
         self.gain = gain
         self.secs = secs
 
@@ -71,7 +74,7 @@ class TimeModel(GObject.GObject):
         cur_time = time()
         whites_time = cur_time + self.getPlayerTime(WHITE)
         blacks_time = cur_time + self.getPlayerTime(BLACK)
-        if whites_time <= blacks_time:
+        if self.movingColor == WHITE:
             the_time = whites_time
             color = WHITE
         else:
@@ -95,6 +98,7 @@ class TimeModel(GObject.GObject):
 
     def __checkzero(self, color):
         if self.getPlayerTime(color) <= 0 and self.started:
+            self.emit("time_changed")
             self.emit('zero_reached', color)
             return False
         return True
@@ -225,11 +229,10 @@ class TimeModel(GObject.GObject):
     def getPlayerTime(self, color, movecount=-1):
         if color == self.movingColor and self.started and movecount == -1:
             if self.paused:
-                return self.intervals[color][movecount] - self.pauseInterval
+                return max(0, self.intervals[color][movecount] - self.pauseInterval)
             elif self.counter:
-                return self.intervals[color][movecount] - (time() -
-                                                           self.counter)
-        return self.intervals[color][movecount]
+                return max(0, self.intervals[color][movecount] - (time() - self.counter))
+        return max(0, self.intervals[color][movecount])
 
     def getInitialTime(self):
         return self.intervals[WHITE][0]
@@ -239,7 +242,7 @@ class TimeModel(GObject.GObject):
         gain = self.gain if ply > 2 else 0
         if len(self.intervals[color]) > movecount:
             return self.intervals[color][movecount - 1] - self.intervals[
-                color][movecount] + gain if movecount > 1 else 0
+                color][movecount] + gain
         else:
             return 0
 
@@ -264,4 +267,4 @@ class TimeModel(GObject.GObject):
 
     def isBlitzFide(self):
         val = 60 * self.minutes + 60 * (self.gain if self.handle_gain else 0)
-        return val <= 600  # Less or equal than 10 minutes for 60 moves and for each player
+        return val > 0 and val <= 600  # Less or equal than 10 minutes for 60 moves and for each player
