@@ -9,6 +9,9 @@ LOCAL, ARTIFICIAL, REMOTE = range(3)
 # Engine strengths
 EASY, INTERMEDIATE, EXPERT = range(3)
 
+# Tools
+TOOL_NONE, TOOL_CHESSDB, TOOL_SCOUTFISH = range(3)
+
 # Player colors
 WHITE, BLACK = range(2)
 
@@ -54,22 +57,13 @@ ABORTED_ADJUDICATION, ABORTED_AGREEMENT, ABORTED_COURTESY, ABORTED_EARLY, \
     ADJOURNED_COURTESY_WHITE, ADJOURNED_COURTESY_BLACK, \
     ADJOURNED_LOST_CONNECTION_WHITE, ADJOURNED_LOST_CONNECTION_BLACK, \
     DRAW_50MOVES, DRAW_ADJUDICATION, DRAW_AGREE, DRAW_CALLFLAG, DRAW_INSUFFICIENT, \
-    DRAW_EQUALMATERIAL, DRAW_LENGTH, DRAW_REPITITION, DRAW_STALEMATE, DRAW_KINGSINEIGHTROW, \
+    DRAW_EQUALMATERIAL, DRAW_LENGTH, DRAW_REPETITION, DRAW_STALEMATE, DRAW_KINGSINEIGHTROW, \
     DRAW_BLACKINSUFFICIENTANDWHITETIME, DRAW_WHITEINSUFFICIENTANDBLACKTIME, \
     WON_ADJUDICATION, WON_CALLFLAG, WON_DISCONNECTION, WON_MATE, WON_RESIGN, \
     WON_LESSMATERIAL, WON_NOMATERIAL, WON_KINGEXPLODE, WON_KINGINCENTER, \
     WON_THREECHECK, WON_KINGINEIGHTROW, WON_WIPEOUT, PRACTICE_GOAL_REACHED, \
     WHITE_ENGINE_DIED, BLACK_ENGINE_DIED, DISCONNECTED, UNKNOWN_REASON = range(43)
 
-UNDOABLE_REASONS = (DRAW_50MOVES, DRAW_INSUFFICIENT, DRAW_LENGTH,
-                    DRAW_REPITITION, DRAW_STALEMATE, DRAW_AGREE, DRAW_CALLFLAG,
-                    DRAW_BLACKINSUFFICIENTANDWHITETIME,
-                    DRAW_WHITEINSUFFICIENTANDBLACKTIME,
-                    WON_MATE, WON_NOMATERIAL, WON_CALLFLAG, WON_RESIGN)
-
-UNRESUMEABLE_REASONS = (DRAW_50MOVES, DRAW_INSUFFICIENT, DRAW_LENGTH,
-                        DRAW_REPITITION, DRAW_STALEMATE, WON_MATE, WON_NOMATERIAL)
-
 ABORTED_REASONS = (ABORTED_ADJUDICATION, ABORTED_AGREEMENT, ABORTED_COURTESY,
                    ABORTED_EARLY, ABORTED_SERVER_SHUTDOWN, ABORTED_DISCONNECTION)
 
@@ -77,6 +71,20 @@ ADJOURNED_REASONS = (ADJOURNED_COURTESY, ADJOURNED_AGREEMENT, ADJOURNED_LOST_CON
                      ADJOURNED_SERVER_SHUTDOWN, ADJOURNED_COURTESY_WHITE, ADJOURNED_COURTESY_BLACK,
                      ADJOURNED_LOST_CONNECTION_WHITE, ADJOURNED_LOST_CONNECTION_BLACK)
 
+UNDOABLE_REASONS = (DRAW_50MOVES, DRAW_INSUFFICIENT, DRAW_EQUALMATERIAL,
+                    DRAW_REPETITION, DRAW_STALEMATE, DRAW_AGREE, DRAW_CALLFLAG,
+                    DRAW_KINGSINEIGHTROW, DRAW_BLACKINSUFFICIENTANDWHITETIME,
+                    DRAW_WHITEINSUFFICIENTANDBLACKTIME,
+                    WON_MATE, WON_NOMATERIAL, WON_CALLFLAG, WON_RESIGN,
+                    WON_LESSMATERIAL, WON_KINGEXPLODE, WON_KINGINCENTER, WON_THREECHECK,
+                    WON_KINGINEIGHTROW, WON_WIPEOUT)
+
+ADJUDICATION_REASONS = (DRAW_ADJUDICATION, WON_ADJUDICATION)
+
+DEATH_REASONS = (WHITE_ENGINE_DIED, BLACK_ENGINE_DIED, DISCONNECTED)
+
+CALLFLAG_REASONS = (DRAW_CALLFLAG, WON_CALLFLAG)
+
 # Player actions
 RESIGNATION = "resignation"
 FLAG_CALL = "flag call"
@@ -165,6 +173,8 @@ W_OO, W_OOO, B_OO, B_OOO = [2**i for i in range(4)]
 CAS_FLAGS = ((W_OOO, W_OO), (B_OOO, B_OO))
 W_CASTLED, B_CASTLED = [2**i for i in range(2)]
 
+NB_OF_CASES = 64
+
 # Cords types
 A1, B1, C1, D1, E1, F1, G1, H1,\
     A2, B2, C2, D2, E2, F2, G2, H2,\
@@ -189,6 +199,7 @@ reprCord = [
 reprFile = ["a", "b", "c", "d", "e", "f", "g", "h"]
 reprRank = ["1", "2", "3", "4", "5", "6", "7", "8"]
 
+# dictionary for giving the cord linked to the flattened index of a coordinate
 cordDic = {}
 for cord, name in enumerate(reprCord):
     cordDic[name] = cord
@@ -220,5 +231,11 @@ VIEW_MENU_ITEMS = ("rotate_board1", "show_sidepanels", "hint_mode", "spy_mode")
 EDIT_MENU_ITEMS = ("copy_pgn", "copy_fen", )
 MENU_ITEMS = GAME_MENU_ITEMS + ACTION_MENU_ITEMS + VIEW_MENU_ITEMS + EDIT_MENU_ITEMS
 
+# Column name
+COLUMN_ROW_RESET = "column_row_reset"
+
+# Gtk icon name
+GTK_ICON_VIEW_REFRESH = "view-refresh"
+
 # Learn categories
 LECTURE, LESSON, PUZZLE, ENDGAME = range(4)
