@@ -1,3 +1,4 @@
+import asyncio
 import re
 from urllib.request import urlopen
 
@@ -12,7 +13,7 @@ from pychess.System.Log import log
 from pychess.System import conf
 
 URL = "http://www.k4it.de/egtb/fetch.php?action=egtb&fen="
-expression = re.compile("(\d+)-(\d+)-?(\d+)?: (Win in \d+|Draw|Lose in \d+)")
+expression = re.compile(r"(\d+)-(\d+)-?(\d+)?: (Win in \d+|Draw|Lose in \d+)")
 PROMOTION_FLAGS = {
     2: QUEEN_PROMOTION,
     3: ROOK_PROMOTION,
@@ -32,25 +33,32 @@ class EgtbK4kit:
     def supports(self, size):
         return sum(size) < 7
 
+    @asyncio.coroutine
     def scoreAllMoves(self, board, probeSoft=False):
         global URL, expression, PROMOTION_FLAGS
         fen = board.asFen().split()[0] + " w - - 0 1"
         if (fen, board.color) in self.table:
             return self.table[(fen, board.color)]
 
-        if probeSoft or not conf.get("online_egtb_check", True):
+        if probeSoft or not conf.get("online_egtb_check"):
             return []
 
-        # Request the page
-        url = (URL + fen).replace(" ", "%20")
-        try:
-            f = urlopen(url)
-        except IOError as e:
-            log.warning(
-                "Unable to read endgame tablebase from the Internet: %s" %
-                repr(e))
-            return []
-        data = f.read()
+        def get_data(URL, fen):
+            # Request the page
+            url = (URL + fen).replace(" ", "%20")
+            try:
+                f = urlopen(url)
+            except IOError as e:
+                log.warning(
+                    "Unable to read endgame tablebase from the Internet: %s" %
+                    repr(e))
+                data = b""
+            data = f.read()
+            return data
+
+        loop = asyncio.get_event_loop()
+        future = loop.run_in_executor(None, get_data, URL, fen)
+        data = yield from future
 
         # Parse
         for color, move_data in enumerate(data.split(b"\nNEXTCOLOR\n")):
