@@ -50,11 +50,9 @@ class ParsingError(Exception):
 
 
 def sittuyin_promotion_fcord(board, tcord):
-    from pychess.Variants import variants
     queenMoves = moveArray[ASEAN_QUEEN]
-    promotion_zone = variants[SITTUYINCHESS].PROMOTION_ZONE[board.color]
     for fcord in iterBits(queenMoves[tcord]):
-        if fcord in promotion_zone:
+        if board.arBoard[fcord]:
             return fcord
 
 ################################################################################
@@ -475,8 +473,7 @@ def parseSAN(board, san):
                         continue
                     return move
 
-    errstring = "no %s is able to move to %s" % (reprPiece[piece],
-                                                 reprCord[tcord])
+    errstring = _("no %(piece)s is able to move to %(cord)s") % {"piece": reprPiece[piece], "cord": reprCord[tcord]}
     raise ParsingError(san, errstring, board.asFen())
 
 ################################################################################
@@ -605,6 +602,15 @@ def parseAN(board, an):
         raise ParsingError(an, "the move must be 4 or 6 chars long",
                            board.asFen())
 
+    if "@" in an:
+        tcord = cordDic[an[-2:]]
+        if an[0].islower():
+            # Sjeng-ism
+            piece = chr2Sign[an[0]]
+        else:
+            piece = chrU2Sign[an[0]]
+        return newMove(piece, tcord, DROP)
+
     try:
         fcord = cordDic[an[:2]]
         tcord = cordDic[an[2:4]]
