@@ -10,11 +10,11 @@ class AutoLogOutManager(GObject.GObject):
 
         self.connection.expect_line(
             self.onLogOut,
-            "\*\*\*\* Auto-logout because you were idle more than \d+ minutes\. \*\*\*\*")
-        self.connection.expect_line(self.onLogOut, "Logging you out\.")
+            r"\*\*\*\* Auto-logout because you were idle more than \d+ minutes\. \*\*\*\*")
+        self.connection.expect_line(self.onLogOut, r"Logging you out\.")
         self.connection.expect_line(
             self.onLogOut,
-            "\*\*\*\* .+? has arrived - you can't both be logged in\. \*\*\*\*")
+            r"\*\*\*\* .+? has arrived - you can't both be logged in\. \*\*\*\*")
 
     def onLogOut(self, match):
         self.emit("logOut")
