@@ -1,17 +1,16 @@
 import os
-import asyncio
-
-from gi.repository import Gtk
 
 from pychess.compat import create_task
 from pychess.System.prefix import addDataPrefix
-from pychess.Utils.const import WHITE, BLACK, LOCAL, NORMALCHESS, ARTIFICIAL, WAITING_TO_START, HINT, PRACTICE_GOAL_REACHED, PUZZLE
+from pychess.Utils.const import WHITE, BLACK, LOCAL, NORMALCHESS, ARTIFICIAL, \
+    WAITING_TO_START, HINT, PRACTICE_GOAL_REACHED, PUZZLE
 from pychess.Utils.LearnModel import LearnModel
 from pychess.Utils.TimeModel import TimeModel
 from pychess.Variants import variants
 from pychess.Players.Human import Human
 from pychess.Players.engineNest import discoverer
 from pychess.perspectives import perspective_manager
+from pychess.perspectives.learn.generateLessonsSidepanel import generateLessonsSidepanel
 from pychess.perspectives.learn import lessons_solving_progress
 from pychess.perspectives.learn import puzzles_solving_progress
 from pychess.Savers.olv import OLVFile
@@ -47,72 +46,7 @@ for elem in sorted(os.listdir(path=addDataPrefix("learn/puzzles/"))):
 
 PUZZLES = puzzles0 + puzzles1 + puzzles2 + puzzles3
 
-
-class Sidepanel():
-    def load(self, persp):
-        self.persp = persp
-        self.box = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
-
-        self.tv = Gtk.TreeView()
-
-        renderer = Gtk.CellRendererText()
-        column = Gtk.TreeViewColumn(_("Title"), renderer, text=1)
-        self.tv.append_column(column)
-
-        renderer = Gtk.CellRendererText()
-        column = Gtk.TreeViewColumn(_("Source"), renderer, text=2)
-        self.tv.append_column(column)
-
-        renderer = Gtk.CellRendererProgress()
-        column = Gtk.TreeViewColumn(_("Progress"), renderer, text=3, value=4)
-        self.tv.append_column(column)
-
-        self.tv.connect("row-activated", self.row_activated)
-
-        def on_progress_updated(solving_progress, key, progress):
-            for i, row in enumerate(self.store):
-                if row[0] == key:
-                    solved = progress.count(1)
-                    percent = 0 if not solved else round((solved * 100.) / len(progress))
-                    treeiter = self.store.get_iter(Gtk.TreePath(i))
-                    self.store[treeiter][3] = "%s / %s" % (solved, len(progress))
-                    self.store[treeiter][4] = percent
-        puzzles_solving_progress.connect("progress_updated", on_progress_updated)
-
-        self.store = Gtk.ListStore(str, str, str, str, int)
-
-        @asyncio.coroutine
-        def coro():
-            for file_name, title, author in PUZZLES:
-                progress = puzzles_solving_progress.get(file_name)
-                solved = progress.count(1)
-                percent = 0 if not solved else round((solved * 100.) / len(progress))
-                self.store.append([file_name, title, author, "%s / %s" % (solved, len(progress)), percent])
-                yield from asyncio.sleep(0)
-        create_task(coro())
-
-        self.tv.set_model(self.store)
-        self.tv.get_selection().set_mode(Gtk.SelectionMode.BROWSE)
-        self.tv.set_cursor(conf.get("learncombo%s" % PUZZLE))
-
-        scrollwin = Gtk.ScrolledWindow()
-        scrollwin.add(self.tv)
-        scrollwin.show_all()
-
-        self.box.pack_start(scrollwin, True, True, 0)
-        self.box.show_all()
-
-        return self.box
-
-    def row_activated(self, widget, path, col):
-        if path is None:
-            return
-        else:
-            filename = PUZZLES[path[0]][0]
-            conf.set("categorycombo", PUZZLE)
-            from pychess.widgets.TaskerManager import learn_tasker
-            learn_tasker.learn_combo.set_active(path[0])
-            start_puzzle_from(filename)
+# Note: Find the declaration of the class Sidepanel at the end of the file
 
 
 def start_puzzle_from(filename, index=None):
@@ -128,7 +62,10 @@ def start_puzzle_from(filename, index=None):
     progress = puzzles_solving_progress.get(filename, [0] * chessfile.count)
 
     if index is None:
-        index = progress.index(0)
+        try:
+            index = progress.index(0)
+        except ValueError:
+            index = 0
 
     rec = records[index]
 
@@ -196,3 +133,12 @@ def start_puzzle_game(gamemodel, filename, records, index, rec, from_lesson=Fals
 
     perspective = perspective_manager.get_perspective("games")
     create_task(perspective.generalStart(gamemodel, p0, p1))
+
+
+# Sidepanel is a class
+Sidepanel = generateLessonsSidepanel(
+    solving_progress=puzzles_solving_progress,
+    learn_category_id=PUZZLE,
+    entries=PUZZLES,
+    start_from=start_puzzle_from,
+)
