@@ -15,7 +15,7 @@ from pychess.System.Log import log
 from pychess.Utils.IconLoader import get_pixbuf
 from pychess.Utils.const import REMOTE, UNFINISHED_STATES, PAUSED, RUNNING, LOCAL, \
     WHITE, BLACK, ACTION_MENU_ITEMS, DRAW, UNDOABLE_STATES, HINT, SPY, WHITEWON, \
-    MENU_ITEMS, BLACKWON, DROP, FAN_PIECES
+    MENU_ITEMS, BLACKWON, DROP, FAN_PIECES, TOOL_CHESSDB, TOOL_SCOUTFISH
 from pychess.Utils.GameModel import GameModel
 from pychess.Utils.Move import listToMoves
 from pychess.Utils.lutils import lmove
@@ -482,7 +482,7 @@ class GameWidget(GObject.GObject):
                 text = repr(self.gamemodel.players[color])
         if with_elo:
             elo = self.gamemodel.tags.get("WhiteElo" if color == WHITE else "BlackElo")
-            if elo:
+            if elo not in [None, '', '?', '0', 0]:
                 text += " (%s)" % str(elo)
         return text
 
@@ -655,10 +655,14 @@ class GameWidget(GObject.GObject):
         prevButton.set_tooltip_text(_("Step back one move"))
         toolbar.insert(prevButton, -1)
 
-        mainButton = Gtk.ToolButton(stock_id=Gtk.STOCK_REDO)
+        mainButton = Gtk.ToolButton(stock_id=Gtk.STOCK_GOTO_FIRST)
         mainButton.set_tooltip_text(_("Go back to the main line"))
         toolbar.insert(mainButton, -1)
 
+        upButton = Gtk.ToolButton(stock_id=Gtk.STOCK_GOTO_TOP)
+        upButton.set_tooltip_text(_("Go back to the parent line"))
+        toolbar.insert(upButton, -1)
+
         nextButton = Gtk.ToolButton(stock_id=Gtk.STOCK_MEDIA_FORWARD)
         nextButton.set_tooltip_text(_("Step forward one move"))
         toolbar.insert(nextButton, -1)
@@ -668,7 +672,7 @@ class GameWidget(GObject.GObject):
         toolbar.insert(lastButton, -1)
 
         filterButton = Gtk.ToolButton(stock_id=Gtk.STOCK_FIND)
-        filterButton.set_tooltip_text(_("Find postion in current database"))
+        filterButton.set_tooltip_text(_("Find position in current database"))
         toolbar.insert(filterButton, -1)
 
         self.saveButton = Gtk.ToolButton(stock_id=Gtk.STOCK_SAVE)
@@ -685,6 +689,7 @@ class GameWidget(GObject.GObject):
         self.cids[firstButton] = firstButton.connect("clicked", on_clicked, self.board.view.showFirst)
         self.cids[prevButton] = prevButton.connect("clicked", on_clicked, self.board.view.showPrev)
         self.cids[mainButton] = mainButton.connect("clicked", on_clicked, self.board.view.backToMainLine)
+        self.cids[upButton] = upButton.connect("clicked", on_clicked, self.board.view.backToParentLine)
         self.cids[nextButton] = nextButton.connect("clicked", on_clicked, self.board.view.showNext)
         self.cids[lastButton] = lastButton.connect("clicked", on_clicked, self.board.view.showLast)
         self.cids[filterButton] = filterButton.connect("clicked", on_clicked, self.find_in_database)
@@ -705,21 +710,42 @@ class GameWidget(GObject.GObject):
     def find_in_database(self):
         persp = perspective_manager.get_perspective("database")
         if persp.chessfile is None:
+            dialogue = Gtk.MessageDialog(pychess.widgets.mainwindow(),
+                                         type=Gtk.MessageType.ERROR,
+                                         buttons=Gtk.ButtonsType.OK,
+                                         message_format=_("No database is currently opened."))
+            dialogue.run()
+            dialogue.destroy()
             return
 
         view = self.board.view
         shown_board = self.gamemodel.getBoardAtPly(view.shown, view.shown_variation_idx)
         fen = shown_board.asFen()
 
-        result = persp.chessfile.get_book_moves(fen)
-        if len(result) == 0:
-            dialogue = Gtk.MessageDialog(pychess.widgets.mainwindow(), type=Gtk.MessageType.WARNING,
+        tool, found = persp.chessfile.has_position(fen)
+        if not found:
+            dialogue = Gtk.MessageDialog(pychess.widgets.mainwindow(),
+                                         type=Gtk.MessageType.WARNING,
                                          buttons=Gtk.ButtonsType.OK,
-                                         message_format=_("Position not in current database"))
+                                         message_format=_("The position does not exist in the database."))
             dialogue.run()
             dialogue.destroy()
         else:
-            persp.chessfile.set_fen_filter(fen)
+            if tool == TOOL_CHESSDB:
+                persp.chessfile.set_fen_filter(fen)
+            elif tool == TOOL_SCOUTFISH:
+                dialogue = Gtk.MessageDialog(pychess.widgets.mainwindow(),
+                                             type=Gtk.MessageType.QUESTION,
+                                             buttons=Gtk.ButtonsType.YES_NO,
+                                             message_format=_("An approximate position has been found. Do you want to display it ?"))
+                response = dialogue.run()
+                dialogue.destroy()
+                if response != Gtk.ResponseType.YES:
+                    return
+
+                persp.chessfile.set_scout_filter({'sub-fen': fen})
+            else:
+                raise RuntimeError('Internal error')
             persp.gamelist.ply = view.shown
             persp.gamelist.load_games()
             perspective_manager.activate_perspective("database")
