@@ -1,5 +1,6 @@
 # -*- coding: UTF-8 -*-
 
+import os
 import os.path
 import gettext
 import locale
@@ -32,8 +33,8 @@ from pychess.System import conf
 from pychess.System.prefix import getDataPrefix, isInstalled, addDataPrefix
 from pychess.Players.engineNest import discoverer
 from pychess.Players.Human import Human
-from pychess.widgets import ImageMenu
-from pychess.widgets import mainwindow
+from pychess.widgets import ImageMenu, mainwindow
+from pychess.widgets.prompttext import getUserTextDialog
 from pychess.widgets.BoardControl import BoardControl
 from pychess.Savers import fen, pgn
 from pychess.Savers.ChessFile import LoadingError
@@ -41,6 +42,7 @@ from pychess.Variants import variants
 from pychess.Variants.normal import NormalBoard
 from pychess.perspectives import perspective_manager
 from pychess.perspectives.games import enddir
+from pychess.Utils.eco import find_opening_fen
 
 # ===============================================================================
 # We init most dialog icons global to make them accessibly to the
@@ -111,7 +113,7 @@ COPY, CLEAR, PASTE, INITIAL = 2, 3, 4, 5
 # ===============================================================================
 
 
-class _GameInitializationMode(object):
+class _GameInitializationMode:
     @classmethod
     def _ensureReady(cls):
         if not hasattr(_GameInitializationMode, "superhasRunInit"):
@@ -419,9 +421,25 @@ class _GameInitializationMode(object):
                     d.show()
                 return
             elif response == INITIAL:
-                lboard = cls.setupmodel.variant(setup=FEN_START).board
+                if os.environ.get('PYCHESS_UNITTEST'):  # The modal dialog cannot be automated in the background
+                    ecofen = FEN_START
+                else:
+                    ecoterms = getUserTextDialog(dialog,
+                                                 _("Start position from the opening book"),
+                                                 _("Type an ECO code or a keyword (with wildcard *):"))
+                    ecofen = find_opening_fen(ecoterms)
+                    if ecofen is None:
+                        if ecoterms != '':
+                            dlgwin = Gtk.MessageDialog(mainwindow(), type=Gtk.MessageType.QUESTION, buttons=Gtk.ButtonsType.YES_NO)
+                            dlgwin.set_markup(_('No position was found. Do you want to use the default setup ?'))
+                            dlgrep = dlgwin.run()
+                            dlgwin.destroy()
+                            if dlgrep != Gtk.ResponseType.YES:
+                                return
+                        ecofen = FEN_START
+                lboard = cls.setupmodel.variant(setup=ecofen).board
                 cls.ini_widgets(lboard.asFen())
-                cls.board_control.emit("action", "SETUP", None, FEN_START)
+                cls.board_control.emit("action", "SETUP", None, ecofen)
                 return
             elif response != Gtk.ResponseType.OK:
                 cls.widgets["newgamedialog"].hide()
@@ -991,6 +1009,8 @@ def createRematch(gamemodel):
 
 
 def loadFileAndRun(uri):
+    if uri in [None, '']:
+        return False
     parts = splitUri(uri)
     uri = parts[1] if len(parts) == 2 else parts[0]
     loader = enddir[uri[uri.rfind(".") + 1:]]
@@ -1002,3 +1022,14 @@ def loadFileAndRun(uri):
     p1 = (LOCAL, Human, (BLACK, black_name), black_name)
     perspective = perspective_manager.get_perspective("games")
     create_task(perspective.generalStart(gamemodel, p0, p1, (uri, loader, 0, -1)))
+    return True
+
+
+def loadPgnAndRun(data):
+    if data in [None, '']:
+        return False
+    perspective = perspective_manager.get_perspective("games")
+    p0 = (LOCAL, Human, (WHITE, _("White")), _("White"))
+    p1 = (LOCAL, Human, (BLACK, _("Black")), _("Black"))
+    create_task(perspective.generalStart(GameModel(), p0, p1, (StringIO(data), enddir['pgn'], 0, -1)))
+    return True
