@@ -185,6 +185,7 @@ class HintTab:
                                                     on_opening_check_toggled)
 
         uistuff.keep(self.widgets["book_depth_max"], "book_depth_max")
+        uistuff.keep(self.widgets["book_check_exact_match"], "book_exact_match")
 
         # Endgame
         egtb_path = conf.get("egtb_path")
@@ -713,8 +714,8 @@ class ThemeTab:
         def onResetColourClicked(_):
             """ :Description: Resets the chess board squares to factory default
             """
-            conf.set("lightcolour", conf.get("lightcolour"))
-            conf.set("darkcolour", conf.get("darkcolour"))
+            conf.set("lightcolour", conf.DEFAULTS["General"]["lightcolour"])
+            conf.set("darkcolour", conf.DEFAULTS["General"]["darkcolour"])
 
         widgets["reset_btn"].connect("clicked", onResetColourClicked)
 
